@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2017 - Sebastien Bihorel
+# Copyright (C) 2010-2018 - Sebastien Bihorel
 #
 # This file must be used under the terms of the CeCILL.
 # This source file is licensed as described in the file COPYING, which
@@ -13,9 +13,9 @@ is.optimsimplex <- function(x=NULL){
   
 }
 
-is.simplex <- function(x=NULL){
+is.osimplex <- function(x=NULL){
   
-  inherits(x,'simplex')
+  inherits(x,'osimplex')
   
 }
 
